#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_grr import SchGRR
from pycatia.cat_sch_platform_interfaces.sch_list_of_bst_rs import SchListOfBSTRs
from pycatia.cat_sch_platform_interfaces.sch_list_of_objects import SchListOfObjects
from pycatia.system_interfaces.any_object import AnyObject


class SchConnectable(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchConnectable
                | 
                | Represents schematic objects that can be connected to others.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_connectable = com_object

    def list_connectors(self, i_l_cntr_class_filter: SchListOfBSTRs, i_grr: SchGRR) -> SchListOfObjects:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ListConnectors(SchListOfBSTRs iLCntrClassFilter,
                | SchGRR iGRR) As SchListOfObjects
                | 
                |     Find all the connectors of this schematic object on a specific graphical
                |     image.
                | 
                |     Parameters:
                | 
                |         oLCntrClassFilter
                |             A list of all the class types for filtering the output connector
                |             list. 
                |         iGRR
                |             Pointer to the graphical image 
                |         oLCntrs
                |             A list of connectors included in this connection. (members are
                |             CATISchAppConnector interface pointers). 
                | 
                |     Example:
                |
                |          Dim objThisIntf As SchConnectable
                |          Dim objArg1 As SchListOfBSTRs
                |          Dim objArg2 As SchGRR
                |          Dim objArg3 As SchListOfObjects
                |           ...
                |          Set objArg3 = objThisIntf.ListConnectors(objArg1,objArg2)

        :param SchListOfBSTRs i_l_cntr_class_filter:
        :param SchGRR i_grr:
        :rtype: SchListOfObjects
        """
        return SchListOfObjects(self.sch_connectable.ListConnectors(i_l_cntr_class_filter.com_object, i_grr.com_object))

    def __repr__(self):
        return f'SchConnectable(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-07-06 14:02:20.222384

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.hybrid_shape_interfaces.hybrid_shape_direction import HybridShapeDirection
from pycatia.in_interfaces.reference import Reference
from pycatia.knowledge_interfaces.angle import Angle
from pycatia.knowledge_interfaces.length import Length
from pycatia.mec_mod_interfaces.hybrid_shape import HybridShape


class HybridShapeExtremumPolar(HybridShape):

    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     MecModInterfaces.HybridShape
                |                         HybridShapeExtremumPolar
                | 
                | Represents the hybrid shape extremum polar feature.
                | Role: To access the data of the extremum polar feature . This data
                | includes:
                | 
                |     The contour
                |     The support (if exist )
                |     The direction of evaluation
                |     The extermum type
                | 
                | Use the HybridShapeFactory.AddNewExtremumPolarto create a
                | HybridShapeExtremumPolar object.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.hybrid_shape_extremum_polar = com_object

    @property
    def angle(self) -> Angle:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Angle() As Angle (Read Only)
                | 
                |     returns the resulting angle of extremum.

        :rtype: Angle
        """

        return Angle(self.hybrid_shape_extremum_polar.Angle)

    @property
    def contour(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Contour() As Reference
                | 
                |     returns or sets the input contour.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_extremum_polar.Contour)

    @contour.setter
    def contour(self, reference_contour: Reference):
        """
        :param Reference reference_contour:
        """

        self.hybrid_shape_extremum_polar.Contour = reference_contour.com_object

    @property
    def dir(self) -> HybridShapeDirection:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Dir() As HybridShapeDirection
                | 
                |     returns or sets the direction of computation.

        :rtype: HybridShapeDirection
        """

        return HybridShapeDirection(self.hybrid_shape_extremum_polar.Dir)

    @dir.setter
    def dir(self, direction: HybridShapeDirection):
        """
        :param HybridShapeDirection direction:
        """

        self.hybrid_shape_extremum_polar.Dir = direction.com_object

    @property
    def extremum_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property ExtremumType() As short
                | 
                |     returns or sets the type of extremum.

        :rtype: int
        """

        return self.hybrid_shape_extremum_polar.ExtremumType

    @extremum_type.setter
    def extremum_type(self, value: int):
        """
        :param int value:
        """

        self.hybrid_shape_extremum_polar.ExtremumType = value

    @property
    def origin(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Origin() As Reference
                | 
                |     returns or sets the origin of the polar axis.

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_extremum_polar.Origin)

    @origin.setter
    def origin(self, reference_origin: Reference):
        """
        :param Reference reference_origin:
        """

        self.hybrid_shape_extremum_polar.Origin = reference_origin.com_object

    @property
    def radius(self) -> Length:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Radius() As Length (Read Only)
                | 
                |     returns the resulting radius of extremum.

        :rtype: Length
        """

        return Length(self.hybrid_shape_extremum_polar.Radius)

    @property
    def support(self) -> Reference:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-07-06 14:02:20.222384)
                | o Property Support() As Reference
                | 
                |     returns or sets the support (if exist).

        :rtype: Reference
        """

        return Reference(self.hybrid_shape_extremum_polar.Support)

    @support.setter
    def support(self, reference_support: Reference):
        """
        :param Reference reference_support:
        """

        self.hybrid_shape_extremum_polar.Support = reference_support.com_object

    def __repr__(self):
        return f'HybridShapeExtremumPolar(name="{ self.name }")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.smt_interfaces.dmo_thickness import DMOThickness
from pycatia.system_interfaces.collection import Collection


class DMOThicknesses(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     DMOThicknesses
                | 
                | Interface to access a CATIADMOThicknesses and compute
                | Thicknesses
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.dmo_thicknesses = com_object

    def add(
            self,
            i_product_to_thickness: Product,
            i_thickness1: float,
            i_thickness2: float,
            i_use_constraints: int,
            i_constraints: tuple,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> DMOThickness:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProductToThickness,
                | double iThickness1,
                | double iThickness2,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As DMOThickness
                | 
                |     Creates a new Silhouette and adds it to the DMOThicknesses collection. This
                |     function is deprecated.

        :param Product i_product_to_thickness:
        :param float i_thickness1:
        :param float i_thickness2:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: DMOThickness
        """
        return DMOThickness(
            self.dmo_thicknesses.Add(
                i_product_to_thickness.com_object,
                i_thickness1,
                i_thickness2,
                i_use_constraints,
                i_constraints,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def compute_a_thickness(
            self,
            group_of_selected_products: Group,
            i_thickness1: float,
            i_thickness2: float,
            i_use_constraints: int,
            i_constraints: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAThickness(Group GroupOfSelectedProducts,
                | double iThickness1,
                | double iThickness2,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints) As Document
                | 
                |     Compute a thickness on the selected products. This method is
                |     deprecated.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the thickness.
                |             
                |         iThickness1
                |             First thickness value. 
                |         iThickness2
                |             Second thickness value. Old way 
                |         iUseConstraints
                |             Do we use normals constraints or not ? 
                |         iConstraints
                |             Constraints array. 
                | 
                |     Returns:
                |         ThicknessDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param float i_thickness1:
        :param float i_thickness2:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :rtype: Document
        """
        return Document(
            self.dmo_thicknesses.ComputeAThickness(
                group_of_selected_products.com_object,
                i_thickness1,
                i_thickness2,
                i_use_constraints,
                i_constraints
            )
        )

    def compute_a_thickness_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_thickness1: float,
            i_thickness2: float,
            i_use_constraints: int,
            i_constraints: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeAThicknessWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | double iThickness1,
                | double iThickness2,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints) As Document
                | 
                |     Compute a thickness on the selected products, according to a reference
                |     product. This method is deprecated.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             The selected products on which you want to perform the thickness.
                |             
                |         iReferenceProduct
                |             The reference product. 
                |         iThickness1
                |             First thickness value. 
                |         iThickness2
                |             Second thickness value. Old way 
                |         iUseConstraints
                |             Do we use normals constraints or not ? 
                |         iConstraints
                |             Constraints array. 
                | 
                |     Returns:
                |         ThicknessDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param float i_thickness1:
        :param float i_thickness2:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :rtype: Document
        """
        return Document(
            self.dmo_thicknesses.ComputeAThicknessWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_thickness1,
                i_thickness2,
                i_use_constraints,
                i_constraints
            )
        )

    def compute_thickness(
            self,
            group_of_selected_products: Group,
            i_thickness1: float,
            i_thickness2: float,
            i_use_constraints: int,
            i_constraints: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeThickness(Group GroupOfSelectedProducts,
                | double iThickness1,
                | double iThickness2,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints) As Document
                | 
                |     Compute a thickness on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the thickness.
                |             
                |         iThickness1
                |             First thickness value. 
                |         iThickness2
                |             Second thickness value. 
                |         iUseConstraints
                |             Do we use normals constraints or not ? 
                |         iConstraints
                |             Constraints array. 
                | 
                |     Returns:
                |         ThicknessDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param float i_thickness1:
        :param float i_thickness2:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :rtype: Document
        """
        return Document(
            self.dmo_thicknesses.ComputeThickness(
                group_of_selected_products.com_object,
                i_thickness1,
                i_thickness2,
                i_use_constraints,
                i_constraints
            )
        )

    def compute_thickness_with_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_thickness1: float,
            i_thickness2: float,
            i_use_constraints: int,
            i_constraints: tuple
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeThicknessWithReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | double iThickness1,
                | double iThickness2,
                | long iUseConstraints,
                | CATSafeArrayVariant iConstraints) As Document
                | 
                |     Compute a thickness on the selected products, according to a reference
                |     product.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             The selected products on which you want to perform the thickness.
                |             
                |         iReferenceProduct
                |             The reference product. 
                |         iThickness1
                |             First thickness value. 
                |         iThickness2
                |             Second thickness value. 
                |         iUseConstraints
                |             Do we use normals constraints or not ? 
                |         iConstraints
                |             Constraints array. 
                | 
                |     Returns:
                |         ThicknessDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param float i_thickness1:
        :param float i_thickness2:
        :param int i_use_constraints:
        :param tuple i_constraints:
        :rtype: Document
        """
        return Document(self.dmo_thicknesses.ComputeThicknessWithReference(i_group_of_selected_products.com_object,
                                                                           i_reference_product.com_object, i_thickness1,
                                                                           i_thickness2, i_use_constraints,
                                                                           i_constraints))

    def thickness_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ThicknessShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.dmo_thicknesses.ThicknessShapeName()

    def __repr__(self):
        return f'DMOThicknesses(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.in_interfaces.document import Document
from pycatia.system_interfaces.any_object import AnyObject


class SchAppModelInit(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppModelInit
                | 
                | Manage the initialization of application model.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_model_init = com_object

    def app_init(self, i_doc: Document) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppInit(Document iDoc)
                | 
                |     Initialize application model.
                | 
                |     Parameters:
                | 
                |         iDoc
                |             Pointer to the document concerned. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppModelInit
                |          Dim objArg1 As Document
                |           ...
                |          objThisIntf.AppInitobjArg1

        :param Document i_doc:
        :rtype: None
        """
        return self.sch_app_model_init.AppInit(i_doc.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_init'
        # # vba_code = """
        # # Public Function app_init(sch_app_model_init)
        # #     Dim iDoc (2)
        # #     sch_app_model_init.AppInit iDoc
        # #     app_init = iDoc
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppModelInit(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.system_interfaces.collection import Collection


class Simplifications(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Simplifications
                | 
                | Interface to compute Simplifications.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.simplifications = com_object

    def compute_simplification(self, group_of_selected_products: Group, i_accuracy: float) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeSimplification(Group GroupOfSelectedProducts,
                | double iAccuracy) As Document
                | 
                |     Computes a simplification on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the
                |             simplification. 
                |         iAccuracy
                |             Accuracy for simplification. 
                | 
                |     Returns:
                |         SimplificationDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param float i_accuracy:
        :rtype: Document
        """
        return Document(self.simplifications.ComputeSimplification(group_of_selected_products.com_object, i_accuracy))

    def compute_simplification_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_accuracy: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeSimplificationWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | double iAccuracy) As Document
                | 
                |     Computes a simplification on the selected products, according to a
                |     reference product.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             The selected products on which you want to perform the
                |             simplification. 
                |         iReferenceProduct
                |             Product taken as a reference. 
                |         iAccuracy
                |             Accuracy for simplification. 
                | 
                |     Returns:
                |         SimplificationDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param float i_accuracy:
        :rtype: Document
        """
        return Document(
            self.simplifications.ComputeSimplificationWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_accuracy
            )
        )

    def simplification_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SimplificationShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.simplifications.SimplificationShapeName()

    def __repr__(self):
        return f'Simplifications(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class MigrBatchSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         MigrBatchSettingAtt
                | 
                | Represents the object to handle the setting parameters of the "Migration Batch"
                | tab page.
                | Role: This interface is implemented by a component named
                | CATV4IMigrBatchSettingCtrl which represents the controller of the Setting. The
                | setting parameters of the tab are the following:
                | 
                |     "Format"
                |     "V4 Part Definition"
                |     "Conversion Mode"
                |     "Display Report Attribute"
                |     "Initial Drawing Path "
                |     "Projection of Space for transparent views"
                |     "Mapping Files Location for Saving "
                |     "Specified Directory "
                |     "Mapping Files Location for Retrieving "
                |     "Interface Name"
                | 
                | To access this property page:
                | 
                |     Click the Options command in the Tools menu
                |     Click + left of General to unfold the workbench list
                |     Click Compatibility
                |     Click on the Migration Batch
                |     tabpage 
                | 
                | 
                | This interface defines:
                | 
                |     A method to get each parameter
                |     A method to set the value of each parameter
                |     A method to lock/unlock each parameter
                |     A method to retrieve the informations concerning each
                |     parameter
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.migr_batch_setting_att = com_object

    @property
    def affiche_attribut(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Affiche_Attribut() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Display Report Attribute" setting
                |     parameter.
                |     Role: This functionality allows the visualization of 3D elements attributes
                |     in the Migration Report. For each element, the list of its attributes is
                |     displayed with their names and values.

        :rtype: str
        """

        return self.migr_batch_setting_att.Affiche_Attribut

    @affiche_attribut.setter
    def affiche_attribut(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Affiche_Attribut = value

    @property
    def mapping_file_save_mode(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mapping_File_Save_Mode() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Mapping Files Location for Saving"
                |     setting parameter.
                |     Role: The "Mapping Files Location for Saving " mode enables you to store a
                |     file which indicates the pointed entities in V4 MML Solids and which allows to
                |     retrieve associativity in CATIA V5. You can specify the directory path of your
                |     choice: Batch Target Directory, Model Directory or Specified Directory.

        :rtype: str
        """

        return self.migr_batch_setting_att.Mapping_File_Save_Mode

    @mapping_file_save_mode.setter
    def mapping_file_save_mode(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Mapping_File_Save_Mode = value

    @property
    def mapping_saving_file(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Mapping_Saving_File() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Specified Directory" setting
                |     parameter.
                |     Role: The "Specified Directory" mode enables you to find pointed entities
                |     in V4 MML Solids and to retrieve associativity in CATIA V5. You can specify the
                |     directory path of your choice.

        :rtype: str
        """

        return self.migr_batch_setting_att.Mapping_Saving_File

    @mapping_saving_file.setter
    def mapping_saving_file(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Mapping_Saving_File = value

    @property
    def migration_format(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Migration_Format() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Format" setting
                |     parameter.
                |     Role: The "Format" mode enables you to select the format of the Migration
                |     in Batch Mode: AS SPEC or AS RESULT.

        :rtype: str
        """

        return self.migr_batch_setting_att.Migration_Format

    @migration_format.setter
    def migration_format(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Migration_Format = value

    @property
    def migration_interface(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Migration_Interface() As CATBSTR
                | 
                |     Retrieves or sets the "Migration Interace" setting
                |     parameter.
                |     Role: This option allows you to customize migrations from CATIA V4 to CATIA
                |     V5. You can choose how your applicative data will be migrated by writing source
                |     code

        :rtype: str
        """

        return self.migr_batch_setting_att.Migration_Interface

    @migration_interface.setter
    def migration_interface(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Migration_Interface = value

    @property
    def migration_type(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Migration_Type() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Conversion Mode" setting
                |     parameter.
                |     Role: The "Conversion Mode" mode enables you to separate the treatment of
                |     SPACE data and DRAW data when a model is migrated.

        :rtype: str
        """

        return self.migr_batch_setting_att.Migration_Type

    @migration_type.setter
    def migration_type(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Migration_Type = value

    @property
    def search_list_size(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Search_List_Size() As long
                | 
                |     Retrieves or sets the size of the "Mapping Files Location for Retrieving"
                |     list.
                |     Role: This setting enables to retrieve the size of the "Mapping Files
                |     Location for Retrieving" list.

        :rtype: int
        """

        return self.migr_batch_setting_att.Search_List_Size

    @search_list_size.setter
    def search_list_size(self, value: int):
        """
        :param int value:
        """

        self.migr_batch_setting_att.Search_List_Size = value

    @property
    def start_up_model_for_drawing(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property StartUp_Model_For_Drawing() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Initial Drawing Path" setting
                |     parameter.
                |     Role: The "Initial Drawing Path" mode enables you to specify a .CATDrawing
                |     document which will serve as a template. The standard used by this document
                |     will be used during the migration.

        :rtype: str
        """

        return self.migr_batch_setting_att.StartUp_Model_For_Drawing

    @start_up_model_for_drawing.setter
    def start_up_model_for_drawing(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.StartUp_Model_For_Drawing = value

    @property
    def v4_part_definition(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property V4_Part_Definition() As CATBSTR
                | 
                |     Retrieves or sets the state of the "V4 Part Definition" setting
                |     parameter.
                |     Role: The "V4 Part Definition" mode enables you to define the CATParts
                |     obtained after the migration: A CATPart by Geometric Set or A CATPart by Solid.
                |     .

        :rtype: str
        """

        return self.migr_batch_setting_att.V4_Part_Definition

    @v4_part_definition.setter
    def v4_part_definition(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.V4_Part_Definition = value

    @property
    def visu_mode_2d(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property Visu_Mode_2D() As CATBSTR
                | 
                |     Retrieves or sets the state of the "Projection of Space for transparent
                |     views" setting parameter.
                |     Role: The "Projection of Space for transparent views" mode enables you to
                |     specify what kind of projection mode you want to use for transparent views
                |     during the migration: NHR, HLR or the same projection mode as the V4 model.

        :rtype: str
        """

        return self.migr_batch_setting_att.Visu_Mode_2D

    @visu_mode_2d.setter
    def visu_mode_2d(self, value: str):
        """
        :param str value:
        """

        self.migr_batch_setting_att.Visu_Mode_2D = value

    def get_affiche_attribut_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAffiche_AttributInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Display Report Attribute" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetAffiche_AttributInfo(admin_level, o_locked)

    def get_mapping_file_save_mode_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMapping_File_Save_ModeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Mapping Files Location for Saving" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetMapping_File_Save_ModeInfo(admin_level, o_locked)

    def get_mapping_saving_file_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMapping_Saving_FileInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Specified Directory" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetMapping_Saving_FileInfo(admin_level, o_locked)

    def get_migration_format_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMigration_FormatInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Format" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetMigration_FormatInfo(admin_level, o_locked)

    def get_migration_interface_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMigration_InterfaceInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Migration Interface" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetMigration_InterfaceInfo(admin_level, o_locked)

    def get_migration_type_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetMigration_TypeInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Conversion" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetMigration_TypeInfo(admin_level, o_locked)

    def get_search_mapping_list(self) -> tuple:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSearch_Mapping_List() As CATSafeArrayVariant
                | 
                |     Retrieves the state of the "Mapping Files Location for Retrieving" setting
                |     parameter.
                |     Role: The "Mapping Files Location for Retrieving " mode enables you to
                |     store a list of mapping tables.

        :rtype: tuple
        """
        return self.migr_batch_setting_att.GetSearch_Mapping_List()

    def get_start_up_model_for_drawing_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetStartUp_Model_For_DrawingInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Initial Drawing Path" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetStartUp_Model_For_DrawingInfo(admin_level, o_locked)

    def get_v4_part_definition_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetV4_Part_DefinitionInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "V4 Part Definition" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetV4_Part_DefinitionInfo(admin_level, o_locked)

    def get_visu_mode_2d_info(self, admin_level: str, o_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetVisu_Mode_2DInfo(CATBSTR AdminLevel,
                | CATBSTR oLocked) As boolean
                | 
                |     Retrieves information about the "Projection of Space for transparent views"
                |     setting parameter.
                |     Refer to SettingController for a detailed description.

        :param str admin_level:
        :param str o_locked:
        :rtype: bool
        """
        return self.migr_batch_setting_att.GetVisu_Mode_2DInfo(admin_level, o_locked)

    def put_search_mapping_list(self, i_rel_path: tuple) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub PutSearch_Mapping_List(CATSafeArrayVariant iRelPath)
                | 
                |     Sets the state of the "Mapping Files Location for Retrieving" setting
                |     parameter.
                |     Role: The "Mapping Files Location for Retrieving " mode enables you to
                |     store a list of mapping tables.

        :param tuple i_rel_path:
        :rtype: None
        """
        return self.migr_batch_setting_att.PutSearch_Mapping_List(i_rel_path)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'put_search_mapping_list'
        # # vba_code = """
        # # Public Function put_search_mapping_list(migr_batch_setting_att)
        # #     Dim iRelPath (2)
        # #     migr_batch_setting_att.PutSearch_Mapping_List iRelPath
        # #     put_search_mapping_list = iRelPath
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_affiche_attribut_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetAffiche_AttributLock(boolean iLock)
                | 
                |     Locks or unlocks the "Display Report Attribute" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetAffiche_AttributLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_affiche_attribut_lock'
        # # vba_code = """
        # # Public Function set_affiche_attribut_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetAffiche_AttributLock iLock
        # #     set_affiche_attribut_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mapping_file_save_mode_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMapping_File_Save_ModeLock(boolean iLock)
                | 
                |     Locks or unlocks the "Mapping Files Location for Saving" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetMapping_File_Save_ModeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mapping_file_save_mode_lock'
        # # vba_code = """
        # # Public Function set_mapping_file_save_mode_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetMapping_File_Save_ModeLock iLock
        # #     set_mapping_file_save_mode_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_mapping_saving_file_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMapping_Saving_FileLock(boolean iLock)
                | 
                |     Locks or unlocks the "Specified Directory" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetMapping_Saving_FileLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_mapping_saving_file_lock'
        # # vba_code = """
        # # Public Function set_mapping_saving_file_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetMapping_Saving_FileLock iLock
        # #     set_mapping_saving_file_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_migration_format_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMigration_FormatLock(boolean iLock)
                | 
                |     Locks or unlocks the "Format" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetMigration_FormatLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_migration_format_lock'
        # # vba_code = """
        # # Public Function set_migration_format_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetMigration_FormatLock iLock
        # #     set_migration_format_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_migration_interface_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMigration_InterfaceLock(boolean iLock)
                | 
                |     Locks or unlocks the "Migration Interface" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetMigration_InterfaceLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_migration_interface_lock'
        # # vba_code = """
        # # Public Function set_migration_interface_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetMigration_InterfaceLock iLock
        # #     set_migration_interface_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_migration_type_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetMigration_TypeLock(boolean iLock)
                | 
                |     Locks or unlocks the "Conversion" setting parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetMigration_TypeLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_migration_type_lock'
        # # vba_code = """
        # # Public Function set_migration_type_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetMigration_TypeLock iLock
        # #     set_migration_type_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_start_up_model_for_drawing_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetStartUp_Model_For_DrawingLock(boolean iLock)
                | 
                |     Locks or unlocks the "Initial Drawing Path" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetStartUp_Model_For_DrawingLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_start_up_model_for_drawing_lock'
        # # vba_code = """
        # # Public Function set_start_up_model_for_drawing_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetStartUp_Model_For_DrawingLock iLock
        # #     set_start_up_model_for_drawing_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_v4_part_definition_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetV4_Part_DefinitionLock(boolean iLock)
                | 
                |     Locks or unlocks the "V4 Part Definition" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetV4_Part_DefinitionLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_v4_part_definition_lock'
        # # vba_code = """
        # # Public Function set_v4_part_definition_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetV4_Part_DefinitionLock iLock
        # #     set_v4_part_definition_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_visu_mode_2d_lock(self, i_lock: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetVisu_Mode_2DLock(boolean iLock)
                | 
                |     Locks or unlocks the "Projection of Space for transparent views" setting
                |     parameter.
                |     Refer to SettingController for a detailed description.

        :param bool i_lock:
        :rtype: None
        """
        return self.migr_batch_setting_att.SetVisu_Mode_2DLock(i_lock)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_visu_mode_2_d_lock'
        # # vba_code = """
        # # Public Function set_visu_mode_2_d_lock(migr_batch_setting_att)
        # #     Dim iLock (2)
        # #     migr_batch_setting_att.SetVisu_Mode_2DLock iLock
        # #     set_visu_mode_2_d_lock = iLock
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'MigrBatchSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from typing import TYPE_CHECKING

from pycatia.cat_plant_ship_interfaces.psp_list_of_bstrs import PSPListOfBSTRs
from pycatia.system_interfaces.any_object import AnyObject

if TYPE_CHECKING:
    from pycatia.cat_plant_ship_interfaces.psp_connectable import PSPConnectable


class PSPConnector(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     PspConnector
                | 
                | Represents connector object.
                | Role: To specify connector behaviors such as connect and
                | disconnect.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.psp_connector = com_object

    @property
    def attr_names(self) -> PSPListOfBSTRs:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property AttrNames() As PspListOfBSTRs
                | 
                |     Returns or Sets Attribute names of the connector.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnector
                |          Dim ojArg1 As CATIAPspListOfBSTRs
                |           ...
                |          Set ojArg1 = objThisIntf.AttrNames

        :rtype: PSPListOfBSTRs
        """

        return PSPListOfBSTRs(self.psp_connector.AttrNames)

    @attr_names.setter
    def attr_names(self, value: PSPListOfBSTRs):
        """
        :param PSPListOfBSTRs value:
        """

        self.psp_connector.AttrNames = value

    @property
    def connector_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property ConnectorName() As CATBSTR
                | 
                |     Returns or sets name of the connector.
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnector
                |          Dim strVar1 As CATBSTR
                |           ...
                |          Set strVar1 = objThisIntf.Name
                |          Dim strVar1 As CATBSTR
                |           ...
                |          objThisIntf.ConnectorName = strVar2

        :rtype: str
        """

        return self.psp_connector.ConnectorName

    @connector_name.setter
    def connector_name(self, value: str):
        """
        :param str value:
        """

        self.psp_connector.ConnectorName = value

    def connect(self, i_cntr_to_connect: 'PSPConnector') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Connect(PspConnector iCntrToConnect)
                | 
                |     Connect the connector to another connector.
                | 
                |     Parameters:
                | 
                |         iCntrToConnect
                |             the connector to be connected to 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnector
                |          Dim objArg1 As PspConnector
                |           ...
                |          objThisIntf.Connect objArg1

        :param PSPConnector i_cntr_to_connect:
        :rtype: None
        """
        return self.psp_connector.Connect(i_cntr_to_connect.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'connect'
        # # vba_code = """
        # # Public Function connect(psp_connector)
        # #     Dim iCntrToConnect (2)
        # #     psp_connector.Connect iCntrToConnect
        # #     connect = iCntrToConnect
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def disconnect(self, i_cntr_to_disconnect: 'PSPConnector') -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Disconnect(PspConnector iCntrToDisconnect)
                | 
                |     DisConnect the connector from another connector.
                | 
                |     Parameters:
                | 
                |         iCntrToDisconnect
                |             The connector to be disconnected from 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnector
                |          Dim objArg1 As PspConnector
                |           ...
                |          objThisIntf.Disconnect objArg1

        :param PSPConnector i_cntr_to_disconnect:
        :rtype: None
        """
        return self.psp_connector.Disconnect(i_cntr_to_disconnect.com_object)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'disconnect'
        # # vba_code = """
        # # Public Function disconnect(psp_connector)
        # #     Dim iCntrToDisconnect (2)
        # #     psp_connector.Disconnect iCntrToDisconnect
        # #     disconnect = iCntrToDisconnect
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def get_associated_connectable(self) -> 'PSPConnectable':
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetAssociatedConnectable() As PspConnectable
                | 
                |     Get the connectable-owner of this connector.
                | 
                |     Parameters:
                | 
                |         oConnectable
                |             Connectable owner of this connector 
                | 
                |     Example:
                |
                |          Dim objThisIntf As PspConnector
                |          Dim objArg1 As CATIAPspConnectable
                |           ...
                |          Set objArg1 = objThisIntf.GetAssociatedConnectable

        :rtype: PSPConnectable
        """
        
        from pycatia.cat_plant_ship_interfaces.psp_connectable import PSPConnectable
        return PSPConnectable(self.psp_connector.GetAssociatedConnectable())

    def is_cntr_connected(self) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func IsCntrConnected() As boolean
                | 
                |     Query whether the connector has been connected.
                | 
                |     Returns:
                |         TRUE if this connector is connected.
                |
                |     Example:
                |
                |          Dim objThisIntf As PspConnector  
                |          Dim bArg1 As boolean  
                |           ...
                |          bArg1 = objThisIntf.IsCntrConnected

        :rtype: bool
        """
        return self.psp_connector.IsCntrConnected()

    def __repr__(self):
        return f'PSPConnector(name="{self.name}")'



#! /usr/bin/python3.9
# module initially auto generated using V5Automation.chm from CATIA R25

from pywintypes import com_error

from pathlib import Path

from pycatia.enumeration.enumeration_types import cat_script_language
from pycatia.exception_handling.exceptions import CATIAApplicationException
from pycatia.in_interfaces.document import Document
from pycatia.in_interfaces.documents import Documents
from pycatia.in_interfaces.file_system import FileSystem
from pycatia.in_interfaces.printer import Printer
from pycatia.in_interfaces.printers import Printers
from pycatia.in_interfaces.send_to_service import SendToService
from pycatia.in_interfaces.system_configuration import SystemConfiguration
from pycatia.in_interfaces.window import Window
from pycatia.in_interfaces.windows import Windows
from pycatia.system_interfaces.any_object import AnyObject
from pycatia.system_interfaces.system_service import SystemService
from pycatia.in_interfaces.setting_controllers import SettingControllers
from pycatia.types.document import document_types


class Application(AnyObject):
    """

    .. note::
        :class: toggle

        CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | System.IUnknown
            |     System.IDispatch
            |         System.CATBaseUnknown
            |             System.CATBaseDispatch
            |                 System.AnyObject
            |                     Application
            |
            | Represents the current CNext application and its frame window.
            | The application is the root object for all the other objects you can use and
            | access from scripts. It directly aggregates:
            |
            |     The document collection represented by the Documents object. This
            |     collection contains all the documents currently opened by the
            |     application
            |     The window collection represented by the Windows object. This collection
            |     contains all the windows currently opened by the application, each window
            |     displaying one of the documents contained in the document
            |     collection
            |     The SystemService object, providing information about the system
            |     environment.
            |
            | The active document and the active window are two key objects for the
            | application you can access using the ActiveDocument and ActiveWindow properties
            | respectively. The active window is the window the end user is currently working
            | in, and the active document is the document displayed in this active window and
            | that the end user is being editing. This document sets its workshop, that is
            | the available menus and toolbars that make it possible to edit it, according to
            | its type.
            |
            | When you create or use macros for in-process access, the application is always
            | referred to as CATIA.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.com_object = com_object

    @property
    def active_document(self) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property ActiveDocument() As Document (Read Only)
            |
            |     Returns the active document. The active document is the document the end
            |     user is being editing.
            |
            |     Example:
            |         This example retrieves in ActiveDoc the active document of the CATIA
            |         application.
            |
            |          Dim ActiveDoc As Document
            |          Set ActiveDoc = CATIA.ActiveDocument

        :rtype: Document
        """
        try:
            active_doc_com = self.com_object.ActiveDocument
            extension = active_doc_com.Name.split('.')[-1]
            types = [document_types[k]['type'] for k in (document_types) if document_types[k]['extension'] == extension]
            if len(types) > 1:
                raise CATIAApplicationException('There was a problem determining the document type.')
            document_type = types[0]
            return document_type(active_doc_com)
        except com_error:
            raise CATIAApplicationException('Is there an active document?')

    @property
    def active_printer(self) -> Printer:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property ActivePrinter() As Printer
            |
            |     Returns or sets the active printer. The active printer is the printer on
            |     which documents are printed
            |
            |     Example:
            |         This example retrieves in ActivePrinter the active printer of the CATIA
            |         application.
            |
            |          Dim ActivePrinter As Printer
            |          Set ActivePrinter = CATIA.ActivePrinter

        :rtype: Printer
        """

        return Printer(self.com_object.ActivePrinter)

    @active_printer.setter
    def active_printer(self, value: Printer):
        """
        :param Printer value:
        """

        self.com_object.ActivePrinter = value

    @property
    def active_window(self) -> Window:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property ActiveWindow() As Window (Read Only)
            |
            |     Returns the active window. The active window is the window in which the end
            |     user is currently editing the active document.
            |
            |     Example:
            |         This example retrieves in ActiveWin the active window of the CATIA
            |         application.
            |
            |          Dim ActiveWin As Window
            |          Set ActiveWin = CATIA.ActiveWindow

        :rtype: Window
        """

        return Window(self.com_object.ActiveWindow)

    @property
    def cache_size(self) -> int:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property CacheSize() As long
            |
            |     Returns or sets the default local cache size used by the
            |     application.
            |
            |     Example:
            |         This example sets the cache size for by the CATIA application to those
            |         defined in LocalCacheSize.
            |
            |          LocalCacheSize= 10
            |          CATIA.CacheSize = LocalCacheSize

        :rtype: int
        """

        return self.com_object.CacheSize

    @cache_size.setter
    def cache_size(self, value: int):
        """
        :param int value:
        """

        self.com_object.CacheSize = value

    @property
    def caption(self) -> str:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Caption() As CATBSTR
            |
            |     Returns or sets the application's window title. This title is displayed in
            |     the application's window title bar.
            |
            |     Example:
            |         This example retrieves in Title the CATIA application's window
            |         title.
            |
            |          Title = CATIA.Caption
            |
            |
            |         The returned value is like this:
            |
            |          CNext

        :rtype: str
        """

        return self.com_object.Caption

    @caption.setter
    def caption(self, value: str):
        """
        :param str value:
        """

        self.com_object.Caption = value

    @property
    def display_file_alerts(self) -> bool:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property DisplayFileAlerts() As boolean
            |
            |     Returns or sets the application ability to display file
            |     alerts.
            |     True if the application enables file alert display.
            |     True is the default. A file alert is, for example, the dialog box that
            |     prompts you that the file you want to save is in read only mode, or that the
            |     file you want to close needs to be saved. It could be handy to disable these
            |     file alerts for automation since they may freeze your macro execution, waiting
            |     for an end user input in the displayed dialog box.
            |
            |     Example:
            |         This example disables file alerts for the CATIA
            |         application.
            |
            |          CATIA.DisplayFileAlerts = False

        :rtype: bool
        """

        return self.com_object.DisplayFileAlerts

    @display_file_alerts.setter
    def display_file_alerts(self, value: bool):
        """
        :param bool value:
        """

        self.com_object.DisplayFileAlerts = value

    @property
    def documents(self) -> Documents:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Documents() As Documents (Read Only)
            |
            |     Returns the collection of documents currently managed by the
            |     application.
            |
            |     Example:
            |         This example retrieves in DocCollection the collection of documents
            |         currently managed by the CATIA application.
            |
            |          Dim DocCollection As Documents
            |          Set DocCollection = CATIA.Documents

        :rtype: Documents
        """
        return Documents(self.com_object.Documents)

    @property
    def file_search_order(self) -> str:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property FileSearchOrder() As CATBSTR
            |
            |     Returns or sets the default path concatenation.
            |     Role: This property returns or sets the default path concatenation used by
            |     Other folders setting of the Linked Documents Localization function. The
            |     primary aim of the Linked Documents Localization function is to resolve
            |     document links and to manage the strategy that will be used to locate your
            |     linked documents.
            |
            |     Example:
            |         This example sets the paths to search for by the CATIA application to
            |         those defined in PathConcatenation.
            |
            |          PathConcatenation = "/u/users/fbq/db/model:/u/users/psr/db/model"
            |          CATIA.FileSearchOrder = PathConcatenation
            |
            |
            |
            |     Theese methods require the installation of CATIA - PPR xPDM Gateway 1
            |     Product (PX1) In case this product is not granted, the first invocation to one
            |     of the methods will fail.

        :rtype: str
        """

        return self.com_object.FileSearchOrder

    @file_search_order.setter
    def file_search_order(self, value: str):
        """
        :param str value:
        """

        self.com_object.FileSearchOrder = value

    @property
    def file_system(self) -> FileSystem:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property FileSystem() As FileSystem (Read Only)
            |
            |     Returns the file system. The file system provides access to a computer's
            |     file system.
            |
            |     Example:
            |         This example retrieves in AppliFileSys the file sytem of the CATIA
            |         application.
            |
            |          Dim AppliFileSys As FileSystem
            |          Set AppliFileSys = CATIA.FileSystem

        :rtype: FileSystem
        """

        return FileSystem(self.com_object.FileSystem)

    @property
    def full_name(self) -> str:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property FullName() As CATBSTR (Read Only)
            |
            |     Returns the application's executable file full name, including its path.
            |     This name is the name of the executable file used to start the
            |     application.
            |
            |     Example:
            |         This example retrieves in ApplicationFullName the CATIA application's
            |         executable file full name.
            |
            |          ApplicationFullName = CATIA.FullName
            |
            |
            |         The returned value is like this:
            |
            |          \\\\lisa\\cxr1arel\\bsf\\alpha_a\\code\\bin\\CNEXT.exe

        :rtype: str
        """

        return self.com_object.FullName

    @property
    def hso_synchronized(self) -> bool:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property HSOSynchronized() As boolean
            |
            |     For selection performance purposes, returns or sets the HSO synchronization
            |     in comparison with the CSO.
            |     Role: Precises if, for all Selection object instances, the HSO (Highlighted
            |     Set of Objects) is synchronized in comparison with the CSO (Current Set of
            |     Objects).
            |
            |     Valid values are:
            |
            |         True: In this case, Selection methods work directly with CATIA's CSO,
            |         to reflect instantly the changes made in Automation Selection. This ensures
            |         correct selection results, but may impact performance in certain
            |         cases.
            |         This is the default value at the beginning of a CATIA
            |         session.
            |         False: In this case, Selection methods work with an internal SO buffer,
            |         which allows faster execution when performing a large number of CSO-independent
            |         Selection calls, or when performing a single Selection call working on a large
            |         number of objects (usually the Search method). This may also prevent the
            |         features from blinking between two user interactions.
            |
            |     Note: even if this property is set to False, the HSO is synchronized in
            |     comparison with the CSO at the begining of the following
            |     methods:
            |
            |         Selection.SelectElement2
            |         Selection.SelectElement3
            |         Selection.SelectElement4
            |         Selection.IndicateOrSelectElement2D
            |         Selection.IndicateOrSelectElement3D
            |         Application.StartCommand
            |
            |     CAUTION: If you use the False value of this property, you must make sure to
            |     reset it to True for CATIA's CSO to reflect properly the changes made in
            |     Automation Selection. For example, it should be reset to True before
            |     interactive parts of your script: MsgBox, InputBox calls, VBA forms updates and
            |     so on.

        :rtype: bool
        """

        return self.com_object.HSOSynchronized

    @hso_synchronized.setter
    def hso_synchronized(self, value: bool):
        """
        :param bool value:
        """

        self.com_object.HSOSynchronized = value

    @property
    def height(self) -> float:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Height() As float
            |
            |     Returns or sets the height of the application's frame window. The height is
            |     expressed in pixels.
            |
            |     Example:
            |         This example sets the height of the CATIA application's frame window to
            |         300 pixels.
            |
            |          CATIA.Height = 300

        :rtype: float
        """

        return self.com_object.Height

    @height.setter
    def height(self, value: float):
        """
        :param float value:
        """

        self.com_object.Height = value

    @property
    def interactive(self) -> bool:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Interactive() As boolean
            |
            |     Returns or sets the application sensitivity to end user
            |     interactions.
            |     True if the application is end user interaction sensitive.
            |
            |     Example:
            |         This example makes the CATIA application sensitive to end user
            |         interactions.
            |
            |          CATIA.Interactive = True

        :rtype: bool
        """

        return self.com_object.Interactive

    @interactive.setter
    def interactive(self, value: bool):
        """
        :param bool value:
        """

        self.com_object.Interactive = value

    @property
    def left(self) -> float:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Left() As float
            |
            |     Returns or sets the distance from the application's frame window left side
            |     to the left side of the screen. This distance is expressed in
            |     pixels.
            |
            |     Example:
            |         This example sets the distance from the CATIA application's frame
            |         window left side to the left side of the screen to 150
            |         pixels.
            |
            |          CATIA.Left = 150

        :rtype: float
        """

        return self.com_object.Left

    @left.setter
    def left(self, value: float):
        """
        :param float value:
        """

        self.com_object.Left = value

    @property
    def local_cache(self) -> str:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property LocalCache() As CATBSTR
            |
            |     Returns or sets the default local cache path used by the
            |     application.
            |
            |     Example:
            |         This example sets the cache path for by the CATIA application to those
            |         defined in LocalCachePath.
            |
            |          LocalCachePath= "/tmp/cache"
            |          CATIA.LocalCache = LocalCachePath

        :rtype: str
        """

        return self.com_object.LocalCache

    @local_cache.setter
    def local_cache(self, value: str):
        """
        :param str value:
        """

        self.com_object.LocalCache = value

    @property
    def path(self) -> Path:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Path() As CATBSTR (Read Only)
            |
            |     Returns the path of the application's executable files.
            |
            |     Example:
            |         This example retrieves in ApplicationPath the path where the CATIA
            |         application executable files are located.
            |
            |          ApplicationPath = CATIA.Path
            |
            |
            |         The returned value is like this:
            |
            |          \\\\lisa\\cxr1arel\\bsf\\alpha_a\\code\\bin

        :rtype: Path
        """

        return Path(self.com_object.Path)

    @property
    def printers(self) -> Printers:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Printers() As Printers (Read Only)
            |
            |     Returns the collection of the printers currently managed by the
            |     application.
            |
            |     Example:
            |         This example retrieves in PrintersCollection the collection of the
            |         printers currently managed by the CATIA application.
            |
            |          Dim PrintersCollection As Windows
            |          Set PrintersCollection = CATIA.Printers

        :rtype: Printers
        """

        return Printers(self.com_object.Printers)

    @property
    def refresh_display(self) -> bool:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property RefreshDisplay() As boolean
            |
            |     Enables or disables the update of the display during the script replay. To
            |     improve performance, this update can be temporarely disabled by setting this
            |     property to False in the script.
            |     True (value set by default) if the application's display is refreshed after
            |     each method call executed in late binding mode . This property does not affect
            |     early binding calls nor the get methods because they are never followed by a
            |     refresh of the display.
            |
            |     Example:
            |         This example makes the update of the CATIA application's display
            |         disabled during the script replay.
            |
            |          CATIA.RefreshDisplay = False

        :rtype: bool
        """

        return self.com_object.RefreshDisplay

    @refresh_display.setter
    def refresh_display(self, value: bool):
        """
        :param bool value:
        """

        self.com_object.RefreshDisplay = value

    @property
    def status_bar(self) -> str:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property StatusBar() As CATBSTR
            |
            |     Returns or sets the text displayed in the application's window status
            |     bar.
            |
            |     Example:
            |         This example retrieves in Text the text displayed in the CATIA
            |         application's window status bar.
            |
            |          Text = CATIA.StatusBar
            |
            |
            |         The returned value is like this:
            |
            |          Welcome to CATIA CxR1

        :rtype: str
        """

        return self.com_object.StatusBar

    @status_bar.setter
    def status_bar(self, value: str):
        """
        :param str value:
        """

        self.com_object.StatusBar = value

    @property
    def system_configuration(self) -> SystemConfiguration:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property SystemConfiguration() As SystemConfiguration (Read
            | Only)
            |
            |     Returns the system configuration object (an object which provides access to
            |     system or configuration dependent resources).
            |
            |     Parameters:
            |
            |         oConfiguration
            |             The system configuration object.

        :rtype: SystemConfiguration
        """

        return SystemConfiguration(self.com_object.SystemConfiguration)

    @property
    def system_service(self) -> SystemService:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property SystemService() As SystemService (Read Only)
            |
            |     Returns system services.
            |
            |     Example:
            |         This example retrieves in AppliSysSer the CATIA application's system
            |         services.
            |
            |          Dim AppliSysSer As SystemService
            |          Set AppliSysSer = CATIA.SystemService

        :rtype: SystemService
        """

        return SystemService(self.com_object.SystemService)

    @property
    def top(self) -> float:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Top() As float
            |
            |     Returns or sets the distance from the application'si frame window top to
            |     the top of the screen. This distance is expressed in
            |     pixels.
            |
            |     Example:
            |         This example sets the distance from the CATIA application's frame
            |         window top to the top of the screen to 50 pixels.
            |
            |          CATIA.Top = 50

        :rtype: float
        """

        return self.com_object.Top

    @top.setter
    def top(self, value: float):
        """
        :param float value:
        """

        self.com_object.Top = value

    @property
    def undo_redo_lock(self) -> bool:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property UndoRedoLock() As boolean
            |
            |     Returns or sets the application status about Undo/Redo.
            |     True if the Undo/Redo mechanism is locked.
            |     False is the default. Since Undo/Redo mechanism uses lots of memory, it can
            |     be useful to disable it during consuming operations. Then Undo and Redo stacks
            |     are flushed and no model modification is kept until the Undo/Redo mechanism is
            |     unlocked. It is mandatory to unlock it before the end of the
            |     macro.
            |
            |     Example:
            |
            |           This example disables Undo/Redo mechanism until it is
            |           unlocked.
            |
            |
            |          CATIA.UndoRedoLock = True

        :rtype: bool
        """

        return self.com_object.UndoRedoLock

    @undo_redo_lock.setter
    def undo_redo_lock(self, value: bool):
        """
        :param bool value:
        """

        self.com_object.UndoRedoLock = value

    @property
    def visible(self) -> bool:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Visible() As boolean
            |
            |     Returns or sets the application's window visibility.
            |     True if the application's window is visible to the end
            |     user.
            |
            |     Example:
            |         This example makes the CATIA application's window
            |         visible.
            |
            |          CATIA.Visibility = True

        :rtype: bool
        """

        return self.com_object.Visible

    @visible.setter
    def visible(self, value: bool):
        """
        :param bool value:
        """

        self.com_object.Visible = value

    @property
    def width(self) -> float:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Width() As float
            |
            |     Returns or sets the width of the application's frame window. The width is
            |     expressed in pixels.
            |
            |     Example:
            |         This example sets the width of the CATIA application's frame window to
            |         350 pixels.
            |
            |          CATIA.Width = 350

        :rtype: float
        """

        return self.com_object.Width

    @width.setter
    def width(self, value: float):
        """
        :param float value:
        """

        self.com_object.Width = value

    @property
    def windows(self) -> Windows:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445)

            | o Property Windows() As Windows (Read Only)
            |
            |     Returns the collection of windows currently managed by the
            |     application.
            |
            |     Example:
            |         This example retrieves in WinCollection the collection of windows
            |         currently managed by the CATIA application.
            |
            |          Dim WinCollection As Windows
            |          Set WinCollection = CATIA.Windows

        :rtype: Windows
        """

        return Windows(self.com_object.Windows)

    def create_send_to(self) -> SendToService:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Func CreateSendTo() As SendToService
            |
            |     Creates a Send TO.
            |     Role:This method creates a SendToService instance.
            |     Warning : CATIASendToService interface requires the
            |     installation of CATIA - PPR xPDM Gateway 1 Product (PX1)
            |     In case this product is not granted, the first invocation
            |     to one of CATIASendToService methods will fail.

        :rtype: SendToService
        """
        return SendToService(self.com_object.CreateSendTo())

    def disable_new_undo_redo_transaction(self) -> None:
        """
        .. note::
            :class: toggle
            
            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Sub DisableNewUndoRedoTransaction()
            |
            |     Prevents new Undo/Redo transaction creation.
            |     If too many Undo/Redo transactions are created during macro execution, it
            |     may affect performance. So it is valuable to prevent Undo/Redo transaction
            |     creation during macro execution when lots of data are created, deleted or
            |     modified.
            |     Note: preventing Undo/Redo transaction creation must not be done when a
            |     selection is required in the macro
            |     Do not forget to call EnableNewUndoRedoTransaction at the end of the macro
            |     or before selection to restore the common behavior.
            |
            |     Example:
            |         This example prevents new transactions to be created, which may
            |         increase performance.
            |
            |          CATIA.DisableNewUndoRedoTransaction()

        :rtype: None
        """
        return self.com_object.DisableNewUndoRedoTransaction()

    def enable_new_undo_redo_transaction(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Sub EnableNewUndoRedoTransaction()
            |
            |     Allows new Undo/Redo transaction creation.
            |
            |     Example:
            |         This example restores the common behavior after
            |         DisableNewUndoRedoTransaction has been called.
            |
            |          CATIA.EnableNewUndoRedoTransaction()

        :rtype: None
        """
        return self.com_object.EnableNewUndoRedoTransaction()

    def file_selection_box(self, i_title: str, i_extension: str, i_mode: int) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Func FileSelectionBox(CATBSTR iTitle,
            | CATBSTR iExtension,
            | CatFileSelectionMode iMode) As CATBSTR
            |
            |     Displays a modal dialog box which can be used to select / enter the name of
            |     a file to open / save.
            |
            |     Parameters:
            |
            |         iTitle
            |             The title of the dialog box.
            |         iExtension
            |             A file extension filter.
            |         iMode
            |             The mode in which to run the dialog box (either
            |             CatFileSelectionModeOpen or CatFileSelectionModeSave.
            |
            |         oFilePath
            |             The return string containing the full path of the selected file, or
            |             a zero-length string if the user selects Cancel.
            |
            |             Example:
            |                 This example asks the user to select a text file and prints the
            |                 path of the selected file.
            |
            |                  filepath = CATIA.FileSelectionBox("Select a text file",
            |                                                     "\\*.txt", CatFileSelectionModeOpen)
            |                  CATIA.SystemServices.Print "The selected file is " &
            |                  filepath

        :param str i_title:
        :param str i_extension:
        :param int i_mode: enum cat_file_selection_mode
        :rtype: str
        """
        return self.com_object.FileSelectionBox(i_title, i_extension, i_mode)

    def get_workbench_id(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Func GetWorkbenchId() As CATBSTR
            |
            |     Returns the identifier of the CATIA current workbench.
            |
            |     Parameters:
            |
            |         oworkbenchId
            |             The id of the current workbench.

        :rtype: str
        """
        return self.com_object.GetWorkbenchId()

    def help(self, i_help_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Sub Help(CATBSTR iHelpID)
            |
            |     Displays application's online help.
            |
            |     Parameters:
            |
            |         iHelpID
            |             Identifier of the help message to display
            |
            |     Example:
            |         This example displays the string referred to by the HelpKey message key
            |         in the message catalog concatenation.
            |
            |          CATIA.Help("HelpKey")

        :param str i_help_id:
        :rtype: None
        """
        return self.com_object.Help(i_help_id)

    def message_box(self, message_text: str, buttons: int = 0, title: str = ""):
        """

        The button values

        =====================   ======= ========================================
        Constant                Value   Description
        ---------------------   ------- ----------------------------------------
        vbOKOnly                0       Display OK button only.
        vbOKCancel              1       Display OK and Cancel buttons.
        vbAbortRetryIgnore      2       Display Abort, Retry, and Ignore buttons
        vbYesNoCancel           3       Display Yes, No, and Cancel buttons.
        vbYesNo                 4       Display Yes and No buttons.
        vbRetryCancel           5       Display Retry and Cancel buttons.
        vbCritical              16      Display Critical Message icon.
        vbQuestion              32      Display Warning Query icon.
        vbExclamation           48      Display Warning Message icon.
        vbInformation           64      Display Information Message icon.
        vbDefaultButton1        0       First button is default.
        vbDefaultButton2        256     Second button is default.
        vbDefaultButton3        512     Third button is default.
        vbDefaultButton4        768     Fourth button is default.
        vbApplicationModal      0       Application modal; the user must respond
                                        to the message box before continuing
                                        work in the current application.
        vbSystemModal           4096    System modal; all applications are
                                        suspended until the user responds to the
                                        message box.
        vbMsgBoxHelpButton      16384   Adds Help button to the message box.
        vbMsgBoxSetForeground   65536   Specifies the message box window as the
                                        foreground window.
        vbMsgBoxRight           524288  Text is right-aligned.
        vbMsgBoxRtlReading      1048576 Specifies text should appear as
                                        right-to-left reading on Hebrew and
                                        Arabic systems.
        =====================   ======= ========================================


        Return values

        ========  =====  ===========
        Constant  Value  Description
        --------  -----  -----------
        vbOK          1  OK
        vbCancel      2  Cancel
        vbAbort       3  Abort
        vbRetry       4  Retry
        vbIgnore      5  Ignore
        vbYes         6  Yes
        vbNo          7  No
        ========  =====  ===========


        Example::

            This creates a message box with the buttons abort, retry ignore and displays the Warning Query icon.

            >>> from pycatia import catia
            >>> buttons = 2 + 32
            >>> result = catia.message_box('Hello World!?', buttons=buttons, title='Asking a question.')
            >>> # result = 3 if the user presses Abort.


        :param str message_text: Text to be displayed in the message box window.
        :param int buttons: Defines the message box configuration. See example.
        :param str title: Text to be displayed in the message box title bar.
        :return: Returns an int which is representative of the button pressed.
        :rtype: int
        """
        function_name = "message_box"
        msg_box = f"Public Function {function_name}(message_text, buttons, title)\n" \
                  f"    {function_name} = MsgBox(message_text, buttons, title)\n" \
                  "End Function"

        return self.system_service.evaluate(
            msg_box,
            cat_script_language.index('CATVBScriptLanguage'),
            function_name,
            [message_text, buttons, title]
        )

    def input_box(
            self,
            prompt: str,
            title: str = '',
            default: str = ''
    ) -> str:
        """
        Display InputBox in catia.
        Default position is in the center screen.

        More information on
        https://learn.microsoft.com/en-us/office/vba/language/reference/user-interface-help/inputbox-function

        :param str prompt: Required. String expression displayed as the message in the dialog box.
        :param str title: Optional. The default is ''. String expression displayed in the title bar of the dialog box.
        :param str default: Optional. The default is ''. String expression displayed in the text box as the default
                                      response if no other input is provided. If you omit default, the text box is
                                      displayed empty.
        :returns: str
        """
        f_name = "input_box"
        i_box = f"Public Function {f_name}(prompt,title,default)\n" \
                f"    {f_name} = InputBox(prompt,title,default)\n" \
                "End Function"
        return self.system_service.evaluate(
            i_box,
            cat_script_language.index('CATVBScriptLanguage'),
            f_name,
            [prompt, title, default]
        )

    def quit(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Sub Quit()
            |
            |     Exits the application and closes all open documents.
            |
            |     Example:
            |         This example exits the CATIA application and closes all its open
            |         documents.
            |
            |          CATIA.Quit()

        :rtype: None
        """
        return self.com_object.Quit()

    def setting_controllers(self) -> SettingControllers:
        """
        Application.SettingControllers
        """
        return SettingControllers(self.com_object.SettingControllers)

    def start_command(self, i_command_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Sub StartCommand(CATBSTR iCommandId)
            |
            |     Starts a CATIA command.
            |     Role:This method starts a command and executes it untill its first
            |     interaction. Please notice interactions such as selections you could add after
            |     in your macro will not work. StartCommand is useful to execute one-shot (not
            |     interactive) commands, it is not safe for interactive
            |     commands.
            |
            |     Parameters:
            |
            |         iCommandId
            |             The id of the command to be started. This id can be the name of the
            |             command or its alias.

        :param str i_command_id:
        :rtype: None
        """
        return self.com_object.StartCommand(i_command_id)

    def start_workbench(self, iworkbench_id: str) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-06-11 12:40:47.360445))

            | o Sub StartWorkbench(CATBSTR iworkbenchId)
            |
            |     Starts a CATIA workbench.
            |
            |     Parameters:
            |
            |         iworkbenchId
            |             The id of the workbench to be started.

        :param str iworkbench_id:
        :rtype: None
        """
        return self.com_object.StartWorkbench(iworkbench_id)

    def __repr__(self):
        return f'Application(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.arrangement_interfaces.arrangement_run import ArrangementRun
from pycatia.in_interfaces.move import Move
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ArrangementRuns(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ArrangementRuns
                | 
                | A collection object of ArrangementRun objects.
                | Role: Use this collection object to manage ArrangementRun
                | objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ArrangementRun)
        self.arrangement_runs = com_object

    def add_run(
            self,
            i_rel_axis: Move,
            i_listof_math_points: tuple,
            i_math_direction: tuple
    ) -> ArrangementRun:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func AddRun(Move iRelAxis,
                | CATSafeArrayVariant iListofMathPoints,
                | CATSafeArrayVariant iMathDirection) As ArrangementRun
                | 
                |     Creates an ArrangementRun and adds it to the collection.
                | 
                |     Parameters:
                | 
                |         iRelAxis
                |             Relative Axis to be considered. 
                |         iListofMathPoints
                |             List of points through which to route. 
                |         iMathDirection
                |             Starting routing direction. 
                | 
                |     Returns:
                |         Returns the newly created ArrangementRun object and adds it to the
                |         collection.

        :param Move i_rel_axis:
        :param tuple i_listof_math_points:
        :param tuple i_math_direction:
        :rtype: ArrangementRun
        """
        return ArrangementRun(
            self.arrangement_runs.AddRun(
                i_rel_axis.com_object,
                i_listof_math_points,
                i_math_direction
            )
        )

    def item(self, i_index: cat_variant) -> ArrangementRun:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ArrangementRun
                | 
                |     Returns the specified ArrangementRun item of the collection
                |     object.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementRun to retrieve from this
                |             collection.
                | 
                |             To retrieve a specific object by number, use the rank of the
                |             ArrangementRun in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To retrieve a specific
                |                 ArrangementRun by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property. 
                |     Returns:
                |         The retrieved ArrangementRun object.

        :param cat_variant i_index:
        :rtype: ArrangementRun
        """
        return ArrangementRun(self.arrangement_runs.Item(i_index))

    def remove(self, i_index: cat_variant) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(CATVariant iIndex)
                | 
                |     Removes the specified ArrangementRun object from the
                |     collection.
                | 
                |     Parameters:
                | 
                |         iIndex
                |             The index or the name of the ArrangementRun to remove from this
                |             collection.
                | 
                |             To remove a specific object by number, use the rank of the
                |             ArrangementRun in that collection.
                |                 Note that the index of the first element in the collection is
                |                 1, and the index of the last element is Count. To remove a specific
                |                 ArrangementRun by name, use name that you assigned using the
                |                 
                | 
                |         AnyObject.Name property.

        :param cat_variant i_index:
        :rtype: None
        """
        return self.arrangement_runs.Remove(i_index)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'remove'
        # # vba_code = """
        # # Public Function remove(arrangement_runs)
        # #     Dim iIndex (2)
        # #     arrangement_runs.Remove iIndex
        # #     remove = iIndex
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'ArrangementRuns(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.in_interfaces.document import Document
from pycatia.navigator_interfaces.group import Group
from pycatia.product_structure_interfaces.product import Product
from pycatia.smt_interfaces.silhouette import Silhouette
from pycatia.system_interfaces.collection import Collection


class Silhouettes(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     Silhouettes
                | 
                | Interface to compute Silhouettes.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=Silhouette)
        self.silhouettes = com_object

    def add(
            self,
            i_product_to_silhouette: Product,
            i_accuracy: float,
            i_azimuts: tuple,
            i_shape_name: str,
            i_activated_shape: int,
            i_default_shape: int
    ) -> Silhouette:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Add(Product iProductToSilhouette,
                | double iAccuracy,
                | CATSafeArrayVariant iAzimuts,
                | CATBSTR iShapeName,
                | long iActivatedShape,
                | long iDefaultShape) As Silhouette
                | 
                |     Creates a new Silhouette and adds it to the Silhouettes collection. This
                |     function is deprecated.
                | 
                |     Returns:
                |         The created Silhouette 
                |     Example:
                |         The following example creates a Silhouette newSilhouette in the
                |         Silhouette collection.
                | 
                |          Set newSilhouette = Silhouettes.Add

        :param Product i_product_to_silhouette:
        :param float i_accuracy:
        :param tuple i_azimuts:
        :param str i_shape_name:
        :param int i_activated_shape:
        :param int i_default_shape:
        :rtype: Silhouette
        """
        return Silhouette(
            self.silhouettes.Add(
                i_product_to_silhouette.com_object,
                i_accuracy,
                i_azimuts,
                i_shape_name,
                i_activated_shape,
                i_default_shape
            )
        )

    def clean_up(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub CleanUp()
                | 
                |     Performs some clean-up.

        :rtype: None
        """
        return self.silhouettes.CleanUp()

    def compute_a_silhouette(
            self,
            group_of_selected_products: Group,
            i_view_points: tuple,
            i_accuracy: float,
            i_accuracy_for_simplification: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeASilhouette(Group GroupOfSelectedProducts,
                | CATSafeArrayVariant iViewPoints,
                | double iAccuracy,
                | double iAccuracyForSimplification) As Document
                | 
                |     Computes a silhouette on the selected products.
                | 
                |     Parameters:
                | 
                |         GroupOfSelectedProducts
                |             The selected products on which you want to perform the silhouette.
                |             
                |         iViewPoints
                |             Array containing the viewpoints (cameras) used to perform the
                |             silhouette. 
                |         iAccuracy
                |             Grain value for the voxels. 
                |         iAccuracyForSimplification
                |             Accuracy for simplification of the silhouette. Let it null for no
                |             simplification. 
                | 
                |     Returns:
                |         SilhouetteDocument: Document containing the result.

        :param Group group_of_selected_products:
        :param tuple i_view_points:
        :param float i_accuracy:
        :param float i_accuracy_for_simplification:
        :rtype: Document
        """
        return Document(
            self.silhouettes.ComputeASilhouette(
                group_of_selected_products.com_object,
                i_view_points,
                i_accuracy,
                i_accuracy_for_simplification
            )
        )

    def compute_a_silhouette_with_a_reference(
            self,
            i_group_of_selected_products: Group,
            i_reference_product: Product,
            i_view_points: tuple,
            i_accuracy: float,
            i_accuracy_for_simplification: float
    ) -> Document:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func ComputeASilhouetteWithAReference(Group
                | iGroupOfSelectedProducts,
                | Product iReferenceProduct,
                | CATSafeArrayVariant iViewPoints,
                | double iAccuracy,
                | double iAccuracyForSimplification) As Document
                | 
                |     Computes a silhouette on the selected products, according to a reference
                |     product.
                | 
                |     Parameters:
                | 
                |         iGroupOfSelectedProducts
                |             The selected products on which you want to perform the silhouette.
                |             
                |         iReferenceProduct
                |             Product taken as a reference. 
                |         iViewPoints
                |             Array containing the viewpoints (cameras) used to perform the
                |             silhouette. 
                |         iAccuracy
                |             Grain value for the voxels. 
                |         iAccuracyForSimplification
                |             Accuracy for simplification of the silhouette. Let it null for no
                |             simplification. 
                | 
                |     Returns:
                |         SilhouetteDocument: Document containing the result.

        :param Group i_group_of_selected_products:
        :param Product i_reference_product:
        :param tuple i_view_points:
        :param float i_accuracy:
        :param float i_accuracy_for_simplification:
        :rtype: Document
        """
        return Document(
            self.silhouettes.ComputeASilhouetteWithAReference(
                i_group_of_selected_products.com_object,
                i_reference_product.com_object,
                i_view_points,
                i_accuracy,
                i_accuracy_for_simplification
            )
        )

    def silhouette_shape_name(self) -> str:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func SilhouetteShapeName() As CATBSTR
                | 
                |     Returns the name of the associated shape.

        :rtype: str
        """
        return self.silhouettes.SilhouetteShapeName()

    def __repr__(self):
        return f'Silhouettes(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.system_interfaces.any_object import AnyObject


class ManufacturingPrecedence(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     ManufacturingPrecedence
                | 
                | Defines a precedence relation between objects.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.manufacturing_precedence = com_object

    @property
    def precedence_type(self) -> int:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property PrecedenceType() As CatManufacturingPrecedenceType (Read
                | Only)
                | 
                |     Returns the type of the precedence.

        :return: enum cat_manufacturing_precedence_type
        :rtype: int
        """

        return self.manufacturing_precedence.PrecedenceType

    @property
    def target_operation(self) -> ManufacturingActivity:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)
                | o Property TargetOperation() As ManufacturingActivity (Read
                | Only)
                | 
                |     Returns the target object of the precedence, but with the Operation
                |     interface if it is.

        :rtype: ManufacturingActivity
        """

        return ManufacturingActivity(self.manufacturing_precedence.TargetOperation)

    def __repr__(self):
        return f'ManufacturingPrecedence(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.cat_sch_platform_interfaces.sch_route import SchRoute
from pycatia.system_interfaces.any_object import AnyObject


class SchAppGapPriority(AnyObject):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     SchAppGapPriority
                | 
                | Manage the graphical representation of a route.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.sch_app_gap_priority = com_object

    def app_choose_gap_priority(self, i_the_other_route: SchRoute, o_priority: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AppChooseGapPriority(SchRoute iTheOtherRoute,
                | CatSchIDLGapPriority oPriority)
                | 
                |     Identify which of 2 intersecting routes should be gapped.
                | 
                |     Parameters:
                | 
                |         iTheOtherRoute
                |             The route intersecting This route. 
                |         oPriority
                |             Gap Priority. 
                | 
                |     Example:
                | 
                |           
                | 
                |          Dim objThisIntf As SchAppGapPriority
                |          Dim objArg1 As SchRoute
                | 
                |           ...
                |          objThisIntf.AppChooseGapPriorityobjArg1,CatSchIDLGapPriority_Enum

        :param SchRoute i_the_other_route:
        :param int o_priority: enum cat_sch_idl_gap_priority
        :rtype: None
        """
        return self.sch_app_gap_priority.AppChooseGapPriority(i_the_other_route.com_object, o_priority)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'app_choose_gap_priority'
        # # vba_code = """
        # # Public Function app_choose_gap_priority(sch_app_gap_priority)
        # #     Dim iTheOtherRoute (2)
        # #     sch_app_gap_priority.AppChooseGapPriority iTheOtherRoute
        # #     app_choose_gap_priority = iTheOtherRoute
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'SchAppGapPriority(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""

from pycatia.system_interfaces.setting_controller import SettingController


class RobAnalysisSettingAtt(SettingController):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.AnyObject
                |                     System.SettingController
                |                         RobAnalysisSettingAtt
                | 
                | Interface to handle parameters of Infrastructure-DELMIA Infrastructure-Robot
                | Analysis Tools Options Tab page.
                | Role: This interface is implemented by a component which represents the
                | controller of Robot Analysis Tools Options parameter settings.
                | 
                |     Methods to set value of each parameter xxx
                |     Methods to get value of each parameter xxx
                |     Methods to get information on each parameter xxx
                |     Methods to lock/unlock value of each parameter xxx
                | 
                | Here is the list of parameters to use and their meaning:
                | 
                |     LinSpeedLimit: defines what behavior you can expect when the TCP linear
                |     speed limits are exeeded.
                |     RotSpeedLimit: defines what behavior you can expect when the TCP rotational
                |     speed limits are exeeded.
                |     LinAccelLimit: defines what behavior you can expect when the TCP linear
                |     acceleration limits are exeeded.
                |     RotAccelLimit: defines what behavior you can expect when the TCP rotational
                |     acceleration limits are exeeded.
                |     LinSpeedColor: defines the highlight color to be used when the TCP linear
                |     speed limits are exceeded.
                |     RotSpeedColor: defines the highlight color to be used when the TCP
                |     rotational speed limits are exceeded.
                |     LinAccelColor: defines the highlight color to be used when the TCP linear
                |     acceleration limits are exceeded.
                |     RotAccelColor: defines the highlight color to be used when the TCP
                |     rotational acceleration limits are exceeded.
                |     ReachColor: defines the highlight color to be used when the "unreachable"
                |     condition is detected.
                |     SingularColor: defines the highlight color to be used when the
                |     "singularity" condition is detected.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object)
        self.rob_analysis_setting_att = com_object

    def get_lin_accel_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinAccelColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LinAccelColor
                |     parameter.
                |     Role:Retrieves the state of the LinAccelColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetLinAccelColorInfo(io_admin_level, io_locked)

    def get_lin_accel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinAccelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LinAccelLimit
                |     parameter.
                |     Role:Retrieves the state of the LinAccelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetLinAccelLimitInfo(io_admin_level, io_locked)

    def get_lin_speed_color_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinSpeedColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LinSpeedColor
                |     parameter.
                |     Role:Retrieves the state of the LinSpeedColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetLinSpeedColorInfo(io_admin_level, io_locked)

    def get_lin_speed_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetLinSpeedLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the LinSpeedLimit
                |     parameter.
                |     Role:Retrieves the state of the LinSpeedLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetLinSpeedLimitInfo(io_admin_level, io_locked)

    def get_reach_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetReachColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment information for the ReachColor
                |     parameter.
                |     Role:Retrieves the state of the ReachColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetReachColorInfo(io_admin_level, io_locked)

    def get_rot_accel_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRotAccelColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RotAccelColor
                |     parameter.
                |     Role:Retrieves the state of the RotAccelColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetRotAccelColorInfo(io_admin_level, io_locked)

    def get_rot_accel_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRotAccelLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RotAccelLimit
                |     parameter.
                |     Role:Retrieves the state of the RotAccelLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetRotAccelLimitInfo(io_admin_level, io_locked)

    def get_rot_speed_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRotSpeedColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RotSpeedColor
                |     parameter.
                |     Role:Retrieves the state of the RotSpeedColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetRotSpeedColorInfo(io_admin_level, io_locked)

    def get_rot_speed_limit_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetRotSpeedLimitInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the RotSpeedLimit
                |     parameter.
                |     Role:Retrieves the state of the RotSpeedLimit parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetRotSpeedLimitInfo(io_admin_level, io_locked)

    def get_singular_colour_info(self, io_admin_level: str, io_locked: str) -> bool:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func GetSingularColorInfo(CATBSTR ioAdminLevel,
                | CATBSTR ioLocked) As boolean
                | 
                |     Retrieves environment informations for the SingularColor
                |     parameter.
                |     Role:Retrieves the state of the SingularColor parameter in the current
                |     environment.
                | 
                |     Parameters:
                | 
                |         ioAdminLevel
                | 
                |             If the parameter is locked, AdminLevel gives the administration
                |             level that imposes the value of the parameter.
                |             If the parameter is not locked, AdminLevel gives the administration
                |             level that will give the value of the parameter after a reset.
                |             
                |         ioLocked
                |             Indicates if the parameter has been locked. 
                | 
                |     Returns:
                |         Indicates if the parameter has been explicitly modified or remain to
                |         the administrated value.

        :param str io_admin_level:
        :param str io_locked:
        :rtype: bool
        """
        return self.rob_analysis_setting_att.GetSingularColorInfo(io_admin_level, io_locked)

    def set_lin_accel_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLinAccelColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the LinAccelColor parameter.
                |     Role:Locks or unlocks the LinAccelColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetLinAccelColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_lin_accel_color_lock'
        # # vba_code = """
        # # Public Function set_lin_accel_color_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetLinAccelColorLock iLocked
        # #     set_lin_accel_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_lin_accel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLinAccelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the LinAccelLimit parameter.
                |     Role:Locks or unlocks the LinAccelLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetLinAccelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_lin_accel_limit_lock'
        # # vba_code = """
        # # Public Function set_lin_accel_limit_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetLinAccelLimitLock iLocked
        # #     set_lin_accel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_lin_speed_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLinSpeedColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the LinSpeedColor parameter.
                |     Role:Locks or unlocks the LinSpeedColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetLinSpeedColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_lin_speed_color_lock'
        # # vba_code = """
        # # Public Function set_lin_speed_color_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetLinSpeedColorLock iLocked
        # #     set_lin_speed_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_lin_speed_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetLinSpeedLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the LinSpeedLimit parameter.
                |     Role:Locks or unlocks the LinSpeedLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetLinSpeedLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_lin_speed_limit_lock'
        # # vba_code = """
        # # Public Function set_lin_speed_limit_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetLinSpeedLimitLock iLocked
        # #     set_lin_speed_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_reach_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetReachColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the ReachColor parameter.
                |     Role:Locks or unlocks the ReachColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetReachColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_reach_color_lock'
        # # vba_code = """
        # # Public Function set_reach_color_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetReachColorLock iLocked
        # #     set_reach_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rot_accel_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRotAccelColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the RotAccelColor parameter.
                |     Role:Locks or unlocks the RotAccelColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetRotAccelColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rot_accel_color_lock'
        # # vba_code = """
        # # Public Function set_rot_accel_color_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetRotAccelColorLock iLocked
        # #     set_rot_accel_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rot_accel_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRotAccelLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the RotAccelLimit parameter.
                |     Role:Locks or unlocks the RotAccelLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetRotAccelLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rot_accel_limit_lock'
        # # vba_code = """
        # # Public Function set_rot_accel_limit_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetRotAccelLimitLock iLocked
        # #     set_rot_accel_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rot_speed_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRotSpeedColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the RotSpeedColor parameter.
                |     Role:Locks or unlocks the RotSpeedColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetRotSpeedColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rot_speed_color_lock'
        # # vba_code = """
        # # Public Function set_rot_speed_color_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetRotSpeedColorLock iLocked
        # #     set_rot_speed_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_rot_speed_limit_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetRotSpeedLimitLock(boolean iLocked)
                | 
                |     Locks or unlocks the RotSpeedLimit parameter.
                |     Role:Locks or unlocks the RotSpeedLimit parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetRotSpeedLimitLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_rot_speed_limit_lock'
        # # vba_code = """
        # # Public Function set_rot_speed_limit_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetRotSpeedLimitLock iLocked
        # #     set_rot_speed_limit_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def set_singular_colour_lock(self, i_locked: bool) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub SetSingularColorLock(boolean iLocked)
                | 
                |     Locks or unlocks the SingularColor parameter.
                |     Role:Locks or unlocks the SingularColor parameter if it is possible in the
                |     current administrative context. In user mode this method will always return
                |     E_FAIL.
                | 
                |     Parameters:
                | 
                |         iLocked
                |             the locking operation to be performed Legal
                |             values:
                |             TRUE : to lock the parameter.
                |             FALSE: to unlock the parameter.

        :param bool i_locked:
        :rtype: None
        """
        return self.rob_analysis_setting_att.SetSingularColorLock(i_locked)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'set_singular_color_lock'
        # # vba_code = """
        # # Public Function set_singular_color_lock(rob_analysis_setting_att)
        # #     Dim iLocked (2)
        # #     rob_analysis_setting_att.SetSingularColorLock iLocked
        # #     set_singular_color_lock = iLocked
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def __repr__(self):
        return f'RobAnalysisSettingAtt(name="{self.name}")'



#! usr/bin/python3.9
"""
    Module initially auto generated using V5Automation files from CATIA V5 R28 on 2020-09-25 14:34:21.593357

    .. warning::
        The notes denoted "CAA V5 Visual Basic Help" are to be used as reference only.
        They are there as a guide as to how the visual basic / catscript functions work
        and thus help debugging in pycatia.
        
"""
from pycatia.manufacturing_interfaces.manufacturing_activity import ManufacturingActivity
from pycatia.manufacturing_interfaces.manufacturing_precedence import ManufacturingPrecedence
from pycatia.system_interfaces.collection import Collection
from pycatia.types.general import cat_variant


class ManufacturingPrecedences(Collection):
    """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357)

                | System.IUnknown
                |     System.IDispatch
                |         System.CATBaseUnknown
                |             System.CATBaseDispatch
                |                 System.Collection
                |                     ManufacturingPrecedences
                | 
                | Interface that manage the precedences for an object of type @
                | CATIAManufacturingActivity.
                | If an object A has objects B and C as precedence constraints, it means that B
                | and C have to be performed before A.
    
    """

    def __init__(self, com_object):
        super().__init__(com_object, child_object=ManufacturingPrecedence)
        self.manufacturing_precedences = com_object

    def add_operation(self, i_object: ManufacturingActivity, i_type: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub AddOperation(ManufacturingActivity iObject,
                | CatManufacturingPrecedenceType iType)
                | 
                |     Adds a new precedence in the collection of precedences. The type of added
                |     object is a CATIAManufacturingActivity.

        :param ManufacturingActivity i_object:
        :param int i_type: enum cat_manufacturing_precedence_type
        :rtype: None
        """
        return self.manufacturing_precedences.AddOperation(i_object.com_object, i_type)
        # # # # Autogenerated comment: 
        # # some methods require a system service call as the methods expects a vb array object
        # # passed to it and there is no way to do this directly with python. In those cases the following code
        # # should be uncommented and edited accordingly. Otherwise completely remove all this.
        # # vba_function_name = 'add_operation'
        # # vba_code = """
        # # Public Function add_operation(manufacturing_precedences)
        # #     Dim iObject (2)
        # #     manufacturing_precedences.AddOperation iObject
        # #     add_operation = iObject
        # # End Function
        # # """

        # # system_service = SystemService(self.application.SystemService)
        # # return system_service.evaluate(vba_code, 0, vba_function_name, [self.com_object])

    def item(self, i_index: cat_variant) -> ManufacturingPrecedence:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Func Item(CATVariant iIndex) As ManufacturingPrecedence
                | 
                |     Returns a precedence object from the precedence collection.

        :param cat_variant i_index:
        :rtype: ManufacturingPrecedence
        """
        return ManufacturingPrecedence(self.manufacturing_precedences.Item(i_index))

    def remove(self, i_index: int) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub Remove(long iIndex)
                | 
                |     Removes an object from the precedences collection. The removed precedence
                |     will be deleted, but not the referenced object attach to this precedence.

        :param int i_index:
        :rtype: None
        """
        return self.manufacturing_precedences.Remove(i_index)

    def remove_all(self) -> None:
        """
        .. note::
            :class: toggle

            CAA V5 Visual Basic Help (2020-09-25 14:34:21.593357))
                | o Sub RemoveAll()
                | 
                |     Removes all objects from the precedences collection.

        :rtype: None
        """
        return self.manufacturing_precedences.RemoveAll()

    def __repr__(self):
        return f'ManufacturingPrecedences(name="{self.name}")'
